ui

package
v0.0.0-...-a3fe26d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 5, 2026 License: GPL-3.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

const (
	ReportedAppName = "way2fa"
)

Variables

This section is empty.

Functions

func Create

func Create(list parse.AccountList) (model, error)

Types

This section is empty.

Directories

Path Synopsis
common
msgs
Package containing custom messages implementing tea.Msg
Package containing custom messages implementing tea.Msg
styles
Contains style variables and routines common to all ui models.
Contains style variables and routines common to all ui models.
Package containing code for the "create new" form page.
Package containing code for the "create new" form page.
Package containind code for the password prompt.
Package containind code for the password prompt.

Jump to